=== modified file 'bzrlib/plugins/launchpad/test_lp_open.py'
--- bzrlib/plugins/launchpad/test_lp_open.py	2012-01-05 14:26:58 +0000
+++ bzrlib/plugins/launchpad/test_lp_open.py	2012-01-09 20:55:07 +0000
@@ -45,8 +45,10 @@
         branch = self.make_branch('non-lp')
         url = 'http://example.com/non-lp'
         branch.lock_write()
-        branch.set_public_branch(url)
-        branch.unlock()
+        try:
+            branch.set_public_branch(url)
+        finally:
+            branch.unlock()
         self.assertEqual(
             ['bzr: ERROR: %s is not registered on Launchpad.' % url],
             self.run_open('non-lp', retcode=3))
@@ -54,9 +56,11 @@
     def test_launchpad_branch_with_public_location(self):
         branch = self.make_branch('lp')
         branch.lock_write()
-        branch.set_public_branch(
-            'bzr+ssh://bazaar.launchpad.net/~foo/bar/baz')
-        branch.unlock()
+        try:
+            branch.set_public_branch(
+                'bzr+ssh://bazaar.launchpad.net/~foo/bar/baz')
+        finally:
+            branch.unlock()
         self.assertEqual(
             ['Opening https://code.launchpad.net/~foo/bar/baz in web '
              'browser'],
@@ -65,11 +69,13 @@
     def test_launchpad_branch_with_public_and_push_location(self):
         branch = self.make_branch('lp')
         branch.lock_write()
-        branch.set_public_branch(
-            'bzr+ssh://bazaar.launchpad.net/~foo/bar/public')
-        branch.set_push_location(
-            'bzr+ssh://bazaar.launchpad.net/~foo/bar/push')
-        branch.unlock()
+        try:
+            branch.set_public_branch(
+                'bzr+ssh://bazaar.launchpad.net/~foo/bar/public')
+            branch.set_push_location(
+                'bzr+ssh://bazaar.launchpad.net/~foo/bar/push')
+        finally:
+            branch.unlock()
         self.assertEqual(
             ['Opening https://code.launchpad.net/~foo/bar/public in web '
              'browser'],
@@ -80,9 +86,11 @@
         # location.
         branch = self.make_branch('lp')
         branch.lock_write()
-        branch.set_push_location(
-            'bzr+ssh://bazaar.launchpad.net/~foo/bar/baz')
-        branch.unlock()
+        try:
+            branch.set_push_location(
+                'bzr+ssh://bazaar.launchpad.net/~foo/bar/baz')
+        finally:
+            branch.unlock()
         self.assertEqual(
             ['Opening https://code.launchpad.net/~foo/bar/baz in web '
              'browser'],
@@ -101,9 +109,11 @@
         # lp-open in a subdirectory of a registered branch should work
         wt = self.make_branch_and_tree('lp')
         wt.branch.lock_write()
-        wt.branch.set_push_location(
-            'bzr+ssh://bazaar.launchpad.net/~foo/bar/baz')
-        wt.branch.unlock()
+        try:
+            wt.branch.set_push_location(
+                'bzr+ssh://bazaar.launchpad.net/~foo/bar/baz')
+        finally:
+            wt.branch.unlock()
         self.build_tree(['lp/a/'])
         self.assertEqual(
             ['Opening https://code.launchpad.net/~foo/bar/baz in web '

=== modified file 'bzrlib/plugins/launchpad/test_register.py'
--- bzrlib/plugins/launchpad/test_register.py	2012-01-05 14:26:58 +0000
+++ bzrlib/plugins/launchpad/test_register.py	2012-01-09 20:55:07 +0000
@@ -176,8 +176,10 @@
     def test_register_no_url_in_published_branch_no_error(self):
         b = self.make_branch('.')
         b.lock_write()
-        b.set_public_branch('http://test-server.com/bzr/branch')
-        b.unlock()
+        try:
+            b.set_public_branch('http://test-server.com/bzr/branch')
+        finally:
+            b.unlock()
         out, err = self.run_bzr(['register-branch', '--dry-run'])
         self.assertEqual('Branch registered.\n', out)
         self.assertEqual('', err)

=== modified file 'bzrlib/tests/blackbox/test_bound_branches.py'
--- bzrlib/tests/blackbox/test_bound_branches.py	2012-01-06 09:12:58 +0000
+++ bzrlib/tests/blackbox/test_bound_branches.py	2012-01-09 20:55:07 +0000
@@ -150,7 +150,8 @@
         self.run_bzr("commit -m child", retcode=3, working_dir='child')
         self.check_revno(1, 'child')
         self.run_bzr('unbind', working_dir='child')
-        child_tree = bzrdir.BzrDir.open('child').open_workingtree()
+        # Refresh the child tree/branch objects as 'unbind' modified them
+        child_tree = child_tree.bzrdir.open_workingtree()
         child_tree.commit(message='child')
         self.check_revno(2, 'child')
 
@@ -201,7 +202,8 @@
 
         self.run_bzr('unbind', working_dir='child')
 
-        child_tree = bzrdir.BzrDir.open('child').open_workingtree()
+        # Refresh the child tree/branch objects as 'unbind' modified them
+        child_tree = child_tree.bzrdir.open_workingtree()
         child_tree.commit(message='child', allow_pointless=True)
         self.check_revno(2, 'child')
 
@@ -212,8 +214,9 @@
         # These branches have diverged, but bind should succeed anyway
         self.run_bzr('bind ../base', working_dir='child')
 
+        # Refresh the child tree/branch objects as 'bind' modified them
+        child_tree = child_tree.bzrdir.open_workingtree()
         # This should turn the local commit into a merge
-        child_tree = bzrdir.BzrDir.open('child').open_workingtree()
         child_tree.update()
         child_tree.commit(message='merged')
         self.check_revno(3, 'child')
@@ -252,7 +255,7 @@
 
         self.run_bzr('unbind', working_dir='child')
         # Refresh the child tree/branch objects as 'bind' modified them
-        child_tree = bzrdir.BzrDir.open('child').open_workingtree()
+        child_tree = child_tree.bzrdir.open_workingtree()
         child_tree.commit(message='child', allow_pointless=True)
         self.check_revno(2, 'child')
         self.check_revno(1, 'base')

=== modified file 'bzrlib/tests/blackbox/test_merge_directive.py'
--- bzrlib/tests/blackbox/test_merge_directive.py	2012-01-05 17:56:30 +0000
+++ bzrlib/tests/blackbox/test_merge_directive.py	2012-01-09 20:55:07 +0000
@@ -45,9 +45,11 @@
         self.tree1 = self.make_branch_and_tree('tree1')
         self.build_tree_contents([('tree1/file', 'a\nb\nc\nd\n')])
         self.tree1.branch.lock_write()
-        self.tree1.branch.get_config_stack().set(
-            'email', 'J. Random Hacker <jrandom@example.com>')
-        self.tree1.branch.unlock()
+        try:
+            self.tree1.branch.get_config_stack().set(
+                'email', 'J. Random Hacker <jrandom@example.com>')
+        finally:
+            self.tree1.branch.unlock()
         self.tree1.add('file')
         self.tree1.commit('foo', rev_id='foo-id')
         self.tree2 = self.tree1.bzrdir.sprout('tree2').open_workingtree()

=== modified file 'bzrlib/tests/blackbox/test_pull.py'
--- bzrlib/tests/blackbox/test_pull.py	2012-01-06 09:12:58 +0000
+++ bzrlib/tests/blackbox/test_pull.py	2012-01-09 20:55:07 +0000
@@ -242,8 +242,10 @@
         parent = branch_b.get_parent()
         branch_b = branch.Branch.open('branch_b')
         branch_b.lock_write()
-        branch_b.set_parent(None)
-        branch_b.unlock()
+        try:
+            branch_b.set_parent(None)
+        finally:
+            branch_b.unlock()
         self.assertEqual(None, branch_b.get_parent())
         # test pull for failure without parent set
         out = self.run_bzr('pull', retcode=3, working_dir='branch_b')
@@ -266,10 +268,12 @@
         uncommit.uncommit(branch=branch_b, tree=tree_b)
         t.delete('branch_b/d')
         self.run_bzr('pull', working_dir='branch_b')
+        # Refresh the branch object as 'pull' modified it
         branch_b = branch_b.bzrdir.open_branch()
         self.assertEqual(branch_b.get_parent(), parent)
         # test explicit --remember
         self.run_bzr('pull ../branch_c --remember', working_dir='branch_b')
+        # Refresh the branch object as 'pull' modified it
         branch_b = branch_b.bzrdir.open_branch()
         self.assertEqual(branch_c.bzrdir.root_transport.base,
                          branch_b.get_parent())

=== modified file 'bzrlib/tests/blackbox/test_push.py'
--- bzrlib/tests/blackbox/test_push.py	2012-01-05 15:54:17 +0000
+++ bzrlib/tests/blackbox/test_push.py	2012-01-09 20:55:07 +0000
@@ -117,7 +117,8 @@
         self.assertEquals(out,
                 ('','bzr: ERROR: These branches have diverged.  '
                  'See "bzr help diverged-branches" for more information.\n'))
-        branch_a = bzrdir.BzrDir.open('branch_a').open_branch()
+        # Refresh the branch as 'push' modified it
+        branch_a = branch_a.bzrdir.open_branch()
         self.assertEquals(osutils.abspath(branch_a.get_push_location()),
                           osutils.abspath(branch_b.bzrdir.root_transport.base))
 
@@ -125,7 +126,8 @@
         uncommit.uncommit(branch=branch_b, tree=tree_b)
         transport.delete('branch_b/c')
         out, err = self.run_bzr('push', working_dir='branch_a')
-        branch_a = bzrdir.BzrDir.open('branch_a').open_branch()
+        # Refresh the branch as 'push' modified it
+        branch_a = branch_a.bzrdir.open_branch()
         path = branch_a.get_push_location()
         self.assertEqual(err,
                          'Using saved push location: %s\n'
@@ -136,7 +138,8 @@
                          branch_b.bzrdir.root_transport.base)
         # test explicit --remember
         self.run_bzr('push ../branch_c --remember', working_dir='branch_a')
-        branch_a = bzrdir.BzrDir.open('branch_a').open_branch()
+        # Refresh the branch as 'push' modified it
+        branch_a = branch_a.bzrdir.open_branch()
         self.assertEquals(branch_a.get_push_location(),
                           branch_c.bzrdir.root_transport.base)
 
@@ -179,11 +182,12 @@
         t.add('file')
         t.commit('commit 1')
         self.run_bzr('push -d tree pushed-to')
-        path = bzrdir.BzrDir.open('tree').open_branch().get_push_location()
+        # Refresh the branch as 'push' modified it and get the push location
+        push_loc = t.branch.bzrdir.open_branch().get_push_location()
         out, err = self.run_bzr('push', working_dir="tree")
         self.assertEqual('Using saved push location: %s\n'
                          'No new revisions or tags to push.\n' %
-                         urlutils.local_path_from_url(path), err)
+                         urlutils.local_path_from_url(push_loc), err)
         out, err = self.run_bzr('push -q', working_dir="tree")
         self.assertEqual('', out)
         self.assertEqual('', err)

=== modified file 'bzrlib/tests/blackbox/test_reconfigure.py'
--- bzrlib/tests/blackbox/test_reconfigure.py	2012-01-05 14:26:58 +0000
+++ bzrlib/tests/blackbox/test_reconfigure.py	2012-01-09 20:55:07 +0000
@@ -250,10 +250,11 @@
                                 % (self.get_url('b1'),))
         self.assertContainsRe(out, '^.*/b2/ is now stacked on ../b1\n$')
         self.assertEquals('', err)
-        b2 = bzrdir.BzrDir.open('b2').open_branch()
+        # Refresh the branch as 'reconfigure' modified it
+        branch_2 = branch_2.bzrdir.open_branch()
         # It should be given a relative URL to the destination, if possible,
         # because that's most likely to work across different transports
-        self.assertEquals('../b1', b2.get_stacked_on_url())
+        self.assertEquals('../b1', branch_2.get_stacked_on_url())
         # commit, and it should be stored into b2's repo
         self.build_tree_contents([('foo', 'new foo')])
         tree_2.commit('update foo')
@@ -262,8 +263,9 @@
         self.assertContainsRe(out,
             '^.*/b2/ is now not stacked\n$')
         self.assertEquals('', err)
-        b2 = bzrdir.BzrDir.open('b2').open_branch()
-        self.assertRaises(errors.NotStacked, b2.get_stacked_on_url)
+        # Refresh the branch as 'reconfigure' modified it
+        branch_2 = branch_2.bzrdir.open_branch()
+        self.assertRaises(errors.NotStacked, branch_2.get_stacked_on_url)
 
     # XXX: Needs a test for reconfiguring stacking and shape at the same time;
     # no branch at location; stacked-on is not a branch; quiet mode.

=== modified file 'bzrlib/tests/blackbox/test_send.py'
--- bzrlib/tests/blackbox/test_send.py	2012-01-05 15:54:17 +0000
+++ bzrlib/tests/blackbox/test_send.py	2012-01-09 20:55:07 +0000
@@ -306,9 +306,10 @@
     def set_config_send_strict(self, value):
         br = branch.Branch.open('local')
         br.lock_write()
-        conf = br.get_config_stack()
-        conf.set('send_strict', value)
-        br.unlock()
+        try:
+            br.get_config_stack().set('send_strict', value)
+        finally:
+            br.unlock()
 
     def assertSendFails(self, args):
         out, err = self.run_send(args, rc=3, err_re=self._default_errors)

=== modified file 'bzrlib/tests/blackbox/test_shell_complete.py'
--- bzrlib/tests/blackbox/test_shell_complete.py	2012-01-05 15:54:17 +0000
+++ bzrlib/tests/blackbox/test_shell_complete.py	2012-01-09 20:55:07 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2012 Canonical Ltd
+# Copyright (C) 2011 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify

=== modified file 'bzrlib/tests/blackbox/test_switch.py'
--- bzrlib/tests/blackbox/test_switch.py	2012-01-05 15:54:17 +0000
+++ bzrlib/tests/blackbox/test_switch.py	2012-01-09 20:55:07 +0000
@@ -153,7 +153,8 @@
         branchb_id = tree2.commit('bar')
         checkout = tree1.branch.create_checkout('heavyco/a', lightweight=False)
         self.run_bzr(['switch', 'branchb'], working_dir='heavyco/a')
-        checkout = BzrDir.open('heavyco/a').open_workingtree()
+        # Refresh checkout as 'switch' modified it
+        checkout = checkout.bzrdir.open_workingtree()
         self.assertEqual(branchb_id, checkout.last_revision())
         self.assertEqual(tree2.branch.base,
                          checkout.branch.get_bound_location())

=== modified file 'bzrlib/tests/blackbox/test_whoami.py'
--- bzrlib/tests/blackbox/test_whoami.py	2012-01-05 15:54:17 +0000
+++ bzrlib/tests/blackbox/test_whoami.py	2012-01-09 20:55:07 +0000
@@ -119,7 +119,9 @@
                           '--directory', 'subdir')
         self.run_bzr(['whoami', '--directory', 'subdir', '--branch',
                       'Changed Identity <changed@identi.ty>'])
-        c = branch.Branch.open('subdir').get_config_stack()
+        # Refresh wt as 'whoami' modified it
+        wt = wt.bzrdir.open_workingtree()
+        c = wt.branch.get_config_stack()
         self.assertEquals('Changed Identity <changed@identi.ty>',
                           c.get('email'))
 

=== modified file 'bzrlib/tests/test_merge_directive.py'
--- bzrlib/tests/test_merge_directive.py	2012-01-05 15:54:17 +0000
+++ bzrlib/tests/test_merge_directive.py	2012-01-09 20:55:07 +0000
@@ -424,8 +424,10 @@
             tree_b.branch.base, patch_type=None, public_branch=branch_c.base)
         self.assertEqual(md.target_branch, tree_b.branch.base)
         tree_b.branch.lock_write()
-        tree_b.branch.set_public_branch('http://example.com')
-        tree_b.branch.unlock()
+        try:
+            tree_b.branch.set_public_branch('http://example.com')
+        finally:
+            tree_b.branch.unlock()
         md2 = self.from_objects(
               tree_a.branch.repository, 'rev2a', 500, 144, tree_b.branch.base,
               patch_type=None, public_branch=branch_c.base)

=== modified file 'bzrlib/tests/test_smart.py'
--- bzrlib/tests/test_smart.py	2012-01-05 14:26:58 +0000
+++ bzrlib/tests/test_smart.py	2012-01-09 20:55:07 +0000
@@ -1296,8 +1296,9 @@
         finally:
             branch.unlock()
         self.assertEqual(smart_req.SuccessfulSmartServerResponse(()), response)
-        refreshed = _mod_branch.Branch.open(branch.base)
-        self.assertEqual(None, refreshed.get_parent())
+        # Refresh branch as SetParentLocation modified it
+        branch = branch.bzrdir.open_branch()
+        self.assertEqual(None, branch.get_parent())
 
     def test_set_parent_something(self):
         branch = self.make_branch('base', format="1.9")

